@@ -1,22 +1,25 @@
-# $Id: /mirror/gungho/lib/Gungho/Base.pm 8892 2007-11-10T14:11:01.888849Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Base.pm 6746 2007-04-24T01:05:24.535007Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
 
 package Gungho::Base;
 use strict;
-use warnings;
-use base qw(Gungho::Base::Class Class::Accessor::Fast);
+use base qw(Class::Accessor::Fast Class::Data::Inheritable);
+use Class::C3;
+INIT { Class::C3::initialize() }
 
-__PACKAGE__->mk_accessors($_) for qw(config);
+__PACKAGE__->mk_classdata(config => {});
 
 sub new
 {
     my $class  = shift;
-    my $self = bless { @_ }, $class;
+    my $self = bless {}, $class;
     return $self;
 }
 
+sub setup {}
+
 1;
 
 __END__
