@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 8769 2007-11-08T05:55:36.931222Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 7087 2007-05-08T02:53:07.334658Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -8,13 +8,12 @@ use strict;
 use warnings;
 use base qw(Gungho::Engine);
 use HTTP::Parser;
+use HTTP::Status;
 use IO::Async::Buffer;
-use IO::Async::Notifier;
 use IO::Socket::INET;
-use Net::DNS;
 
 __PACKAGE__->mk_classdata($_) for qw(impl_class);
-__PACKAGE__->mk_accessors($_) for qw(context impl loop_delay resolver);
+__PACKAGE__->mk_accessors($_) for qw(context impl loop_delay);
 
 # probe for available impl_class
 use constant HAVE_IO_POLL => (eval { use IO::Poll } && !$@);
@@ -27,9 +26,7 @@ sub setup
     $self->setup_impl_class($c);
 
     $self->loop_delay( $self->config->{loop_delay} ) if $self->config->{loop_delay};
-    if (! $self->config->{dns}{disable}) {
-        $self->resolver(Net::DNS::Resolver->new);
-    }
+
 }
 
 sub setup_impl_class
@@ -58,69 +55,16 @@ sub run
 }
 
 sub send_request
-{
-    my ($self, $c, $request) = @_;
-
-    if ($self->resolver && $request->requires_name_lookup) {
-        $self->lookup_host($c, $request);
-    } else {
-        $request->uri->host( $request->notes('resolved_ip') )
-            if $request->notes('resolved_ip');
-        if ( ! $c->request_is_allowed($request)) {
-            return;
-        }
-        $self->start_request($c, $request);
-    }
-}
-
-sub handle_response
-{
-    my ($self, $c, $req, $res) = @_;
-    if (my $host = $req->notes('original_host')) {
-        # Put it back
-        $req->uri->host($host);
-    }
-    $c->handle_response($req, $c->prepare_response($res) );
-}
-
-sub lookup_host
-{
-    my ($self, $c, $request) = @_;
-
-    my $resolver = $self->resolver;
-    my $bgsock   = $resolver->bgsend($request->uri->host);
-    my $notifier = IO::Async::Notifier->new(
-        handle => $bgsock,
-        on_read_ready => sub {
-            $self->impl->remove($_[0]);
-            $self->handle_dns_response(
-                $c,
-                $request,
-                $resolver->bgread($bgsock), 
-            );
-        }
-    );
-    $self->impl->add($notifier);
-}
-
-sub start_request
 {
     my ($self, $c, $req) = @_;
     my $uri  = $req->uri;
+
     my $socket = IO::Socket::INET->new(
         PeerAddr => $uri->host,
         PeerPort => $uri->port || $uri->default_port,
         Blocking => 0,
     );
-    if ($@) {
-        $self->handle_response(
-            $c,
-            $req,
-            $c->_http_error(500, "Failed to connect to " . $uri->host . ": $@
-", $req)
-        );
-        return;
-    }
+    die if $@;
 
     my $buffer = IO::Async::Buffer->new(
         handle => $socket,
@@ -132,23 +76,20 @@ sub start_request
             $$buffref = '';
 
             if ($st == 0) {
-                my $res = $parser->object;
-                $c->run_hook('engine.handle_response', { request => $req, response => $res });
-                $self->handle_response($c, $notifier->{request}, $res);
+                $c->handle_response($notifier->{request}, $parser->object);
                 $notifier->handle_closed();
                 $self->impl->remove($notifier);
             }
         },
         on_read_error => sub {
             my $notifier = shift;
-            my $res = $c->_http_error(400, "incomplete response", $notifier->{request});
-            $c->handle_response($c, $notifier->{request}, $res);
+            my $res = $self->_http_error(400, "incomplete response", $notifier->{request});
+            $c->handle_response($notifier->{request}, $res);
         },
         on_write_error => sub {
             my $notifier = shift;
-            my $res = $c->_http_error(500, "Could not write to socket ", $notifier->{request});
-            $c->run_hook('engine.handle_response', { request => $req, response => $res });
-            $self->handle_response($c, $notifier->{request}, $res);
+            my $res = $self->_http_error(500, "Could not write to socket ", $notifier->{request});
+            $c->handle_response($notifier->{request}, $res);
         }
     );
 
@@ -156,11 +97,33 @@ sub start_request
     $buffer->{parser}  = HTTP::Parser->new(response => 1);
     $buffer->{request} = $req;
 
-    $c->run_hook('engine.send_request', { request => $req });
     $buffer->send($req->format);
     $self->impl->add($buffer);
 }
 
+# Stolen from PoCo::Client::HTTP::Request
+sub _http_error
+{
+    my ($self, $code, $message, $request) = @_;
+
+    my $nl = "\n";
+    my $r = HTTP::Response->new($code);
+    my $http_msg = status_message($code);
+    my $m = (
+      "<html>$nl"
+      . "<HEAD><TITLE>Error: $http_msg</TITLE></HEAD>$nl"
+      . "<BODY>$nl"
+      . "<H1>Error: $http_msg</H1>$nl"
+      . "$message$nl"
+      . "</BODY>$nl"
+      . "</HTML>$nl"
+    );
+
+    $r->content($m);
+    $r->request($request);
+    return $r;
+}
+
 package Gungho::Engine::IO::Async::Impl::Select;
 use strict;
 use warnings;
@@ -203,16 +166,6 @@ __END__
 
 Gungho::Engine::IO::Async - IO::Async Engine
 
-=head1 SYNOPSIS
-
-  engine:
-    module: IO::Async
-    config:
-        loop_delay: 0.01
-        dns:
-            disable: 1 # Only if you don't want Gungho to resolve DNS
-
-
 =head1 DESCRIPTION
 
 This class uses IO::Async to dispatch requests.
@@ -230,10 +183,4 @@ In particular, this class definitely should cache connections.
 
 =head2 send_request
 
-=head2 handle_response
-
-=head2 start_request
-
-=head2 lookup_host
-
 =cut
