@@ -1,8 +1,11 @@
-# $Id: /mirror/gungho/lib/Gungho/Exception.pm 6461 2007-04-11T03:53:55.931149Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Exception.pm 7061 2007-05-07T03:31:40.439848Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
 
+package Gungho::Exception;
+use strict;
+use warnings;
 use Exception::Class
     'Gungho::Exception',
     map {
@@ -16,6 +19,6 @@ __END__
 
 =head1 NAME
 
-Gungho::Exception
+Gungho::Exception - Gungho Exceptions
 
 =cut
